@@ -1,10 +1,10 @@
 use aoko::no_std::algebraic::sum::TimeUnit;
-use clap::{Parser, AppSettings};
+use clap::Parser;
 
 /// A CLI tool for converting "str to hex" or "hex to str"
 
 #[derive(Parser)]
-#[clap(global_setting=AppSettings::DisableHelpFlag, version = "0.1.2", author = "hzqd <hzqelf@yeah.net>")]
+#[clap(disable_help_flag = true, version = "0.1.3", author = "hzqd <hzqelf@yeah.net>")]
 pub struct Args {
     /// Convert str to hex
     #[clap(short, long, default_value = "")]
