@@ -9,7 +9,10 @@ fn byt32() -> (impl FnOnce(Duration) -> u128, TimeUnit) {
         (true, true) => str_to_hex(&s).pipe(|_| hex_to_str(&h)),
         (true, false) => str_to_hex(&s),
         (false, true) => hex_to_str(&h),
-        (false, false) => panic!("No input provided"),
+        (false, false) => {
+            print!("Use -h for 'hex to str'\n");
+            println!("Use -s for 'str to hex'");
+        },
     }
     time_conversion_with_unit(unit)
 }
